.. _spider_tuwien.ac.at:

tuwien.ac.at
------------
Newest Mitteilungsblätter issued by `TU Wien <https://tuwien.ac.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``tuwien.ac.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     tuwien.ac.at
